Updating branch refs/heads/master
         to 1c88058f01cdf07cc1684869fe987d8a75f65d9d (commit)
       from 43799c770bd9ec61d1380a0dbff776a0d4e07da8 (commit)

commit 1c88058f01cdf07cc1684869fe987d8a75f65d9d
Author: Nick Schermer <[email protected]>
Date:   Wed Nov 17 20:03:41 2010 +0100

    Fix compiler warnings about shadowed variables.

 thunar/sexy-url-label.c    |   20 ++++++++++----------
 thunar/thunar-tree-model.c |    8 ++++----
 thunar/thunar-view.c       |   16 ++++++++--------
 thunar/thunar-view.h       |    2 +-
 4 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/thunar/sexy-url-label.c b/thunar/sexy-url-label.c
index 198b2cd..0be9e1d 100644
--- a/thunar/sexy-url-label.c
+++ b/thunar/sexy-url-label.c
@@ -217,7 +217,7 @@ sexy_url_label_motion_notify_event(GtkWidget *widget, 
GdkEventMotion *event)
        GList *l;
        int idx, trailing;
        int x, y;
-       SexyUrlLabelLink *link = NULL;
+       SexyUrlLabelLink *llink = NULL;
 
        if (event->is_hint)
                gdk_window_get_pointer(event->window, &x, &y, &state);
@@ -235,9 +235,9 @@ sexy_url_label_motion_notify_event(GtkWidget *widget, 
GdkEventMotion *event)
        {
                for (l = priv->links; l != NULL; l = l->next)
                {
-                       link = (SexyUrlLabelLink *)l->data;
+                       llink = (SexyUrlLabelLink *)l->data;
 
-                       if (idx >= link->start && idx <= link->end)
+                       if (idx >= llink->start && idx <= llink->end)
                        {
                                found = TRUE;
                                break;
@@ -256,7 +256,7 @@ sexy_url_label_motion_notify_event(GtkWidget *widget, 
GdkEventMotion *event)
                        gdk_window_set_cursor(priv->event_window, cursor);
                        gdk_cursor_unref(cursor);
 
-                       priv->active_link = link;
+                       priv->active_link = llink;
                }
        }
        else
@@ -573,17 +573,17 @@ sexy_url_label_rescan_label(SexyUrlLabel *url_label)
                        gint start, end;
                        PangoRectangle start_pos;
                        PangoRectangle end_pos;
-                       SexyUrlLabelLink *link;
+                       SexyUrlLabelLink *llink;
 
                        pango_attr_iterator_range(iter, &start, &end);
                        pango_layout_index_to_pos(layout, start, &start_pos);
                        pango_layout_index_to_pos(layout, end,   &end_pos);
 
-                       link = g_new0(SexyUrlLabelLink, 1);
-                       link->start = start;
-                       link->end   = end;
-                       link->url   = (const gchar *)url_list->data;
-                       priv->links = g_list_append(priv->links, link);
+                       llink = g_new0(SexyUrlLabelLink, 1);
+                       llink->start = start;
+                       llink->end   = end;
+                       llink->url   = (const gchar *)url_list->data;
+                       priv->links = g_list_append(priv->links, llink);
 
                        url_list = url_list->next;
                }
diff --git a/thunar/thunar-tree-model.c b/thunar/thunar-tree-model.c
index 11f04e7..13c2107 100644
--- a/thunar/thunar-tree-model.c
+++ b/thunar/thunar-tree-model.c
@@ -1392,7 +1392,7 @@ thunar_tree_model_item_files_removed (ThunarTreeModelItem 
*item,
   GNode           *child_node;
   GNode           *node;
   GList           *lp;
-  GSList          *link;
+  GSList          *inv_link;
 
   _thunar_return_if_fail (THUNAR_IS_FOLDER (folder));
   _thunar_return_if_fail (item->folder == folder);
@@ -1436,14 +1436,14 @@ thunar_tree_model_item_files_removed 
(ThunarTreeModelItem *item,
       for (lp = files; lp != NULL; lp = lp->next)
         {
           /* find the file in the hidden list */
-          link = g_slist_find (item->invisible_children, lp->data);
-          if (link != NULL)
+          inv_link = g_slist_find (item->invisible_children, lp->data);
+          if (inv_link != NULL)
             {
               /* release the file */
               g_object_unref (G_OBJECT (lp->data));
 
               /* remove from the list */
-              item->invisible_children = g_slist_delete_link 
(item->invisible_children, link);
+              item->invisible_children = g_slist_delete_link 
(item->invisible_children, inv_link);
             }
         }
     }
diff --git a/thunar/thunar-view.h b/thunar/thunar-view.h
index 63b7232..7a6db6d 100644
--- a/thunar/thunar-view.h
+++ b/thunar/thunar-view.h
@@ -87,7 +87,7 @@ gboolean        thunar_view_get_visible_range   (ThunarView   
  *view,
 
 void            thunar_view_scroll_to_file      (ThunarView     *view,
                                                  ThunarFile     *file,
-                                                 gboolean        select,
+                                                 gboolean        select_file,
                                                  gboolean        use_align,
                                                  gfloat          row_align,
                                                  gfloat          col_align);
_______________________________________________
Xfce4-commits mailing list
[email protected]
http://foo-projects.org/mailman/listinfo/xfce4-commits

Reply via email to
diff --git a/thunar/thunar-view.c b/thunar/thunar-view.c
index 067bc09..cd196cb 100644
--- a/thunar/thunar-view.c
+++ b/thunar/thunar-view.c
@@ -294,12 +294,12 @@ thunar_view_get_visible_range (ThunarView  *view,
 
 /**
  * thunar_view_scroll_to_file:
  * @view      : a #ThunarView instance.
  * @file      : the #ThunarFile to scroll to.
  * @select    : %TRUE to also select the @file in the @view.
  * @use_align : whether to use alignment arguments.
  * @row_align : the vertical alignment.
  * @col_align : the horizontal alignment.
  *
  * Tells @view to scroll to the @file. If @view is currently
  * loading, it'll remember to scroll to @file later when
@@ -308,7 +308,7 @@ thunar_view_get_visible_range (ThunarView  *view,
 void
 thunar_view_scroll_to_file (ThunarView *view,
                             ThunarFile *file,
-                            gboolean    select,
+                            gboolean    select_file,
                             gboolean    use_align,
                             gfloat      row_align,
                             gfloat      col_align)
@@ -317,7 +317,7 @@ thunar_view_scroll_to_file (ThunarView *view,
   _thunar_return_if_fail (THUNAR_IS_FILE (file));
   _thunar_return_if_fail (row_align >= 0.0f && row_align <= 1.0f);
   _thunar_return_if_fail (col_align >= 0.0f && col_align <= 1.0f);
-  (*THUNAR_VIEW_GET_IFACE (view)->scroll_to_file) (view, file, select, 
use_align, row_align, col_align);
+  (*THUNAR_VIEW_GET_IFACE (view)->scroll_to_file) (view, file, select_file, 
use_align, row_align, col_align);
 }
 
@@ -294,12 +294,12 @@ thunar_view_get_visible_range (ThunarView  *view,
 /**
  * thunar_view_scroll_to_file:
- * @view      : a #ThunarView instance.
- * @file      : the #ThunarFile to scroll to.
- * @select    : %TRUE to also select the @file in the @view.
- * @use_align : whether to use alignment arguments.
- * @row_align : the vertical alignment.
- * @col_align : the horizontal alignment.
+ * @view        : a #ThunarView instance.
+ * @file        : the #ThunarFile to scroll to.
+ * @select_file : %TRUE to also select the @file in the @view.
+ * @use_align   : whether to use alignment arguments.
+ * @row_align   : the vertical alignment.
+ * @col_align   : the horizontal alignment.
  *
  * Tells @view to scroll to the @file. If @view is currently
 